#!/bin/bash

# Directory to store marker files for run-once logic
MARKER_DIR="/var/www/hydrocontrol/updatemarker"
SCRIPT_DIR="/var/www/hydrocontrol/hydrocontrol.webapi/SystemUpdateScripts"
mkdir -p $MARKER_DIR

# List of all available upgrade versions and their corresponding scripts
declare -A UPGRADES=(
  ["1_0_0_0"]="update_hc0127_1_0_0_0"
  ["1_1_0_0"]="update_hc0127_1_1_0_0"
  ["1_2_0_0"]="update_hc0127_1_2_0_0"
  ["1_3_0_0"]="update_hc0127_1_3_0_0"
  # Add new versions here
)

# Variable to track if any updates have been applied
UPDATE_APPLIED=0

# Loop through the available upgrades
for VERSION in "${!UPGRADES[@]}"; do
  UPDATE_SCRIPT="${UPGRADES[$VERSION]}.sh"

  # Marker file for this version
  MARKER_FILE="$MARKER_DIR/$VERSION"

  # Check if the marker file exists (i.e., update has already been applied)
  if [ -f "$MARKER_FILE" ]; then
    echo "Update $VERSION has already been applied. Skipping."
    continue
  fi

  # Check for the corresponding update script in the ZIP
  UPDATE_SCRIPT_PATH="$SCRIPT_DIR/$UPDATE_SCRIPT"
  if [ ! -f "$UPDATE_SCRIPT_PATH" ]; then
    echo "Error: Update script $UPDATE_SCRIPT_PATH not found."
    exit 1
  fi

  # Make the update script executable and run it
  chmod +x "$UPDATE_SCRIPT_PATH"
  $UPDATE_SCRIPT_PATH

  # Create the marker file to indicate this version has been applied
  touch "$MARKER_FILE"

  # Mark that an update has been applied
  UPDATE_APPLIED=1

  echo "Update $VERSION has been successfully applied."
done
# If an update was applied, reboot the system
if [ $UPDATE_APPLIED -eq 1 ]; then
  echo "Rebooting the system to complete updates..."
  sudo reboot
fi