#!/bin/bash

# Custom update logic for version 1.2.0.0
echo "Applying update for version 1.2.0.0..."

# Remove the obsolete service file
OBSOLETE_SERVICE="/etc/systemd/system/hydrocontrol-webapi-oauth.service"
if [ -f "$OBSOLETE_SERVICE" ]; then
    rm -f "$OBSOLETE_SERVICE"
    echo "Removed obsolete service: $OBSOLETE_SERVICE."
else
    echo "No obsolete service file found."
fi

# Path to the service file
SERVICE_FILE="/etc/systemd/system/hydrocontrol-webapi.service"

# Line to add
LINE="EnvironmentFile=/etc/environment"

# Check if the line is already in the file
grep -q "$LINE" $SERVICE_FILE

# If the line is not found, insert it after the User=root line
if [ $? -ne 0 ]; then
  sed -i "/User=root/a $LINE" $SERVICE_FILE

  # Reload systemd to apply the changes
  systemctl daemon-reload

  echo "Service file updated with EnvironmentFile."
else
  echo "EnvironmentFile line is already in the service file."
fi

# Disable root login via SSH
sed -i 's/PermitRootLogin yes/PermitRootLogin no/g' /etc/ssh/sshd_config
echo "Disabled root login via SSH."

# Lock the root account
passwd -l root
echo "Locked the root account."

# Copy certificates to /home/hydrocontrol/
echo "Copying certificates..."
cp /home/hydrocontrol/hydrocontrol/hydrocontrol.webapi/Certificates/* /home/hydrocontrol/
echo "Certificates copied."

# Update the self-signed.conf
echo "Updating self-signed.conf..."
sed -i 's|ssl_certificate /etc/ssl/certs/hc07.crt;|ssl_certificate /etc/ssl/certs/HydroControl7.crt;|g' /etc/nginx/snippets/self-signed.conf
sed -i 's|ssl_certificate_key /etc/ssl/private/hc07.key;|ssl_certificate_key /etc/ssl/private/HydroControl7.key;|g' /etc/nginx/snippets/self-signed.conf
echo "self-signed.conf updated."

# Move new certificates to the specified directories
echo "Installing new certificates..."
mv /home/hydrocontrol/HydroControl7.crt /etc/ssl/certs/
mv /home/hydrocontrol/HydroControl7.key /etc/ssl/private/
echo "New certificates installed."

# Verify Nginx configuration
echo "Verifying Nginx configuration..."
nginx -t
if [ $? -eq 0 ]; then
  echo "Nginx configuration is valid."
  # Reload Nginx to apply the changes
  echo "Reloading Nginx..."
  systemctl reload nginx
  echo "Nginx reloaded."
else
  echo "Nginx configuration test failed. Not reloading."
fi

echo "Update for version 1.2.0.0 applied successfully."
