#!/bin/bash

# Custom update logic for version 1.3.0.0
echo "Applying update for version 1.3.0.0..."

echo "" > /etc/dhcpcd.conf

# Define the path to the Raspberry Pi config file
CONFIG_FILE="/boot/config.txt"

# RTC configuration to add if not already present
RTC_CONFIG="dtoverlay=i2c-rtc,ds1307,addr=0x68"

# Check if the RTC configuration is already in the config.txt file
if ! grep -q "^${RTC_CONFIG}$" "$CONFIG_FILE"; then
    # If the configuration is not found, append it to the file
    echo "Adding RTC configuration to $CONFIG_FILE: $RTC_CONFIG"
    echo "$RTC_CONFIG" >> "$CONFIG_FILE"
else
    echo "RTC configuration already exists: $RTC_CONFIG"
fi

# Path to the nginx configuration file
NGINX_CONF="/etc/nginx/nginx.conf"

# Check if 'client_max_body_size' is already set in the 'http' section
if ! grep -Pzoq 'http\s*{[^}]*client_max_body_size 512M;' "$NGINX_CONF"; then
    
    sudo sed -i '/http {/a \\tclient_max_body_size 512M;' "$NGINX_CONF"

    echo "Updated Nginx configuration. Restarting Nginx service..."
    sudo service nginx restart
else
    echo "'client_max_body_size 512M;' is already set in the Nginx configuration."
fi

echo "Update for version 1.3.0.0 applied successfully."
