#include <stdio.h>
#include <stdlib.h>
#include <stdbool.h>
#include <fcntl.h>
#include <unistd.h>
#include <sys/ioctl.h>
#include <k8055.h>
#include <string.h>
#include "gpioDriver.h"

#include <linux/i2c-dev.h>
#include <i2c/smbus.h>


//i2c Bussus
static const int DIGITAL_IO_BUS = 1;
static const int ANALOGUE_IO_BUS = 4;

// Digital IO
//MCP23008 addresses:
static const int DIGITAL_OUTPUT_MUX = 0X20;
static const int DIGITAL_INPUT_MUX = 0x21;
static const int WATER_METER_MUX = 0x22;
static const int ADMIX_METER_MUX = 0x23;
static const int RECIPE_MUX = 0x24;

//MCP23008 Registers:
static const __u8 IODIR = 0x00; //GPIO Direction
static const __u8 OLAT = 0x0A;  //Output latch
static const __u8 GPIO_REG = 0x09; //Input register
static const __u8 GPINTEN = 0x02; //Interrupt on Change regiser
static const __u8 GPPU = 0x06; //Pull-up resistor configuration

// Counter GPIOs
static const int READ_ADMIX_METER = 23;
static const int READ_WATER_METER = 24;

//Analogue Output
//LTC2633 Registers
static const int DAC_ADDRESS = 0x10;
static const __u8 DAC_CONFIG = 0x7F; //External reference, all DACs
static const __u8 DAC_OUTPUT_A = 0x30; //Output Analogue 0
static const __u8 DAC_OUTPUT_B = 0x31; //Output Analogue 1

//Analogue Input
//AD7993-1 Registers
static const int ADC_ADDRESS = 0x23;
static const __u8 ADC_CONFIG = 0x02;
static const __u8 ADC_RESULT = 0x00;
static const __u8 ADC_CHANNEL_0 = 0x10;
static const __u8 ADC_CHANNEL_1 = 0x20;

//Velleman K8055 Addresses
static const int K8055_MAIN_IO = 0;
static const int K8055_EXPANSION_IO = 1;





// PUBLIC FUNCTIONS

int listK8055Devices(void);
int checkDigitalInputs();       // Returns 0 on a pass or returns value of non matching bits
int checkDigitalOutputs();      // Returns 0 on a pass or returns value of non matching bits
int checkWaterMeter();          // Reutrns 0 if number of pulses sent/received match (5), otherwise returns number of pulses detected.
int checkExpansionPresent();    // Returns 0 if Expansion board is found or -1 if not found.
int checkRecipeInputs();        // Returns 0 on a pass or returns value of non matching bits
int checkAnalogueInputs();      // Returns 0 if both pass, 1 if AN0 fails, 2 if AN1 fails, 3 if both fail
int checkAnalogueOutputs();     // Returns 0 if both pass, 1 if AN0 fails, 2 if AN1 fails, 3 if both fail
//int checkUSB();               // Not working
int LEDTest(bool LEDState);

int selfTest();